@@ -194,8 +194,8 @@ void OpenconnectAuthWidget::readConfig()
         }
     }
     if (!dataMap[NM_OPENCONNECT_KEY_PROTOCOL].isEmpty()) {
-        const QString protocol = dataMap[NM_OPENCONNECT_KEY_PROTOCOL] == "juniper" ? "nc" : "anyconnect";
-        openconnect_set_protocol(d->vpninfo, OC3DUP(protocol.toUtf8().data()));
+        const QString protocol = dataMap[NM_OPENCONNECT_KEY_PROTOCOL];
+        openconnect_set_protocol(d->vpninfo, OC3DUP(protocol == "juniper" ? "nc" : protocol.toUtf8().data()));
     }
 }
 
@@ -253,7 +253,13 @@ void OpenconnectAuthWidget::readSecrets()
 
 void OpenconnectAuthWidget::acceptDialog()
 {
-    QDialog *dialog = qobject_cast<QDialog*>(parentWidget());
+    // Find top-level widget as this should be the QDialog itself
+    QWidget *widget = parentWidget();
+    while (widget->parentWidget() != nullptr) {
+        widget = widget->parentWidget();
+    }
+
+    QDialog *dialog = qobject_cast<QDialog*>(widget);
     if (dialog) {
         dialog->accept();
     }
